import { EventEmitter, Component, ViewChild, Output, Input, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

class StimulsoftDesignerComponent {
    constructor() {
        /**
         * Occurs when designer loaded
         */
        this.designerLoaded = new EventEmitter();
        this.id = 'aDesigner' + (Math.random() * 10000000).toString();
        this.loaded = false;
    }
    ngOnInit() {
        this.addScript();
    }
    ngOnChanges(changes) {
        this.addScript();
    }
    addScript() {
        if (this.chartScripts) {
            this.head.removeChild(this.chartScripts);
        }
        this.chartScripts = document.createElement('Script');
        this.chartScripts.setAttribute('type', 'text/javascript');
        this.chartScripts.src = this.requestUrl;
        this.chartScripts.addEventListener('load', () => {
            if (!this.loaded) {
                try {
                    const options = new Stimulsoft.Designer.StiDesignerOptions();
                    this.loaded = true;
                    setTimeout(() => {
                        this.designerLoaded.next(null);
                    });
                    this.showDesigner();
                }
                catch (_a) { }
            }
        });
        this.head.appendChild(this.chartScripts);
    }
    showDesigner() {
        const options = new Stimulsoft.Designer.StiDesignerOptions();
        if (this.width) {
            options.width = this.width;
        }
        if (this.height) {
            options.height = this.height;
        }
        this.designer = new Stimulsoft.Designer.StiDesigner(options, 'StiDesigner', false);
        this.designer.renderHtml(this.designerEl.nativeElement);
    }
    get head() {
        return document.getElementsByTagName('head')[0];
    }
}
StimulsoftDesignerComponent.decorators = [
    { type: Component, args: [{
                selector: 'stimulsoft-designer-angular',
                template: `
    <div #designer [attr.id]="id">
      <ng-content></ng-content>
    </div>
  `
            },] }
];
StimulsoftDesignerComponent.ctorParameters = () => [];
StimulsoftDesignerComponent.propDecorators = {
    designerEl: [{ type: ViewChild, args: ['designer',] }],
    designerLoaded: [{ type: Output }],
    requestUrl: [{ type: Input }],
    width: [{ type: Input }],
    height: [{ type: Input }]
};

class StimulsoftDesignerModule {
}
StimulsoftDesignerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [StimulsoftDesignerComponent],
                imports: [
                    CommonModule
                ],
                exports: [StimulsoftDesignerComponent]
            },] }
];

/*
 * Public API Surface of stimulsoft-designer-angular
 */

/**
 * Generated bundle index. Do not edit.
 */

export { StimulsoftDesignerComponent, StimulsoftDesignerModule };
//# sourceMappingURL=stimulsoft-designer-angular.js.map
